@@ -19,7 +19,7 @@ def autowired(func: Callable) -> Callable:
         func_annotation: Dict[str, Type[T]] = inspect.getfullargspec(func).annotations
         for key_param, key_type in func_annotation.items():
             if key_type in services:
-                kwargs[key_param] = services_dict.get(get_context(), DEFAULT)[key_type]()
+                kwargs[key_param] = services_dict.get(get_context(), services_dict[DEFAULT])[key_type]()
         func(*args, **kwargs)
 
     return wrapper
